def get_bedlines():
    bed_lines = ["# chrom\tchromStart\tchromEnd\tF3\tF4\tF5\tF6\tF7\t"
                    "readCount\tmeanCoverage\tpercentage10\tpercentage20"
                    "\tpercentage100\tsampleName",
                 "1\t69089\t70007\t1-69090-70007\t0\t+\tCCDS30547.1\tOR4F5\t"
                    "232\t25.4946\t57.9521\t36.0566\t5.55556\tADM992A10\t"]
    return bed_lines
